@@ -143,13 +143,6 @@ class LuaScripts(object):
             end
 
             local function update_profile_prop (p_key, v_key, obj, field_type)
-                if obj.update_condition then
-                    if not (redis.call('EXISTS', obj.update_condition) == 1) then
-                        return
-                    else
-                        redis.call('DEL', obj.update_condition)
-                    end
-                end
             
                 local current_value = redis.call('HGET', p_key, v_key)
                 local v = obj["value"]
@@ -221,43 +214,49 @@ class LuaScripts(object):
                     local updated_key = obj["key"] .. "{updated_postfix}"
                     local created_key = obj["key"] .. "{created_postfix}"
                     local expire_key = obj["key"] .. "{expire_postfix}"
-
-                    if redis.call('HEXISTS', profile_key, value_key) == 0 then
-                        -- the key does not exist yet
-                        if (obj.expire_at == nil or obj.expire_at > timestamp_now) and obj["value"] ~= nil then
-                            -- only create if the new expire time is in the future
-                            update_profile_prop(profile_key, value_key, obj, field_type)
-                            redis.call('HMSET', profile_key, updated_key, timestamp_now, created_key, timestamp_now)
-                            if obj.expire_at ~= nil then
-                                redis.call('HSET', profile_key, expire_key, obj.expire_at)  
+                    
+                    if not obj.update_condition or (obj.update_condition and not (redis.call('EXISTS', obj.update_condition) == 1)) then
+                    
+                        if redis.call('HEXISTS', profile_key, value_key) == 0 then
+                            -- the key does not exist yet
+                            if (obj.expire_at == nil or obj.expire_at > timestamp_now) and obj["value"] ~= nil then
+                                -- only create if the new expire time is in the future
+                                update_profile_prop(profile_key, value_key, obj, field_type)
+                                redis.call('HMSET', profile_key, updated_key, timestamp_now, created_key, timestamp_now)
+                                if obj.expire_at ~= nil then
+                                    redis.call('HSET', profile_key, expire_key, obj.expire_at)  
+                                end
+                            end
+                        else
+                            -- the key already exists
+                            local deleted_key = false
+                            local current_expire = tonumber(redis.call('HGET', profile_key, expire_key))
+                            if (current_expire ~= nil and current_expire <= timestamp_now) or (obj.expire_at ~= nil and obj.expire_at <= timestamp_now) then
+                                -- first delete if the old or new expire time is in the past
+                                redis.call('HDEL', profile_key, value_key)
+                                redis.call('HDEL', profile_key, updated_key)
+                                redis.call('HDEL', profile_key, created_key)
+                                redis.call('HDEL', profile_key, expire_key)
+                                deleted_key = true
+                            end
+                            if obj.expire_at == nil or obj.expire_at > timestamp_now then
+                                -- create/update the key if its not expired
+                                if obj["value"] ~= nil or not deleted_key then
+                                    update_profile_prop(profile_key, value_key, obj, field_type)
+                                    redis.call('HSET', profile_key, updated_key, timestamp_now)  
+                                    if deleted_key then
+                                        redis.call('HSET', profile_key, created_key, timestamp_now)
+                                    end
+                                    if obj.expire_at ~= nil then
+                                        redis.call('HSET', profile_key, expire_key, obj.expire_at)
+                                    end
+                                end  
                             end
                         end
-                    else
-                        -- the key already exists
-                        local deleted_key = false
-                        local current_expire = tonumber(redis.call('HGET', profile_key, expire_key))
-                        if (current_expire ~= nil and current_expire <= timestamp_now) or (obj.expire_at ~= nil and obj.expire_at <= timestamp_now) then
-                            -- first delete if the old or new expire time is in the past
-                            redis.call('HDEL', profile_key, value_key)
-                            redis.call('HDEL', profile_key, updated_key)
-                            redis.call('HDEL', profile_key, created_key)
-                            redis.call('HDEL', profile_key, expire_key)
-                            deleted_key = true
-                        end
-                        if obj.expire_at == nil or obj.expire_at > timestamp_now then
-                            -- create/update the key if its not expired
-                            if obj["value"] ~= nil or not deleted_key then
-                                update_profile_prop(profile_key, value_key, obj, field_type)
-                                redis.call('HSET', profile_key, updated_key, timestamp_now)  
-                                if deleted_key then
-                                    redis.call('HSET', profile_key, created_key, timestamp_now)
-                                end
-                                if obj.expire_at ~= nil then
-                                    redis.call('HSET', profile_key, expire_key, obj.expire_at)
-                                end
-                            end  
-                        end
-                    end                        
+                    end
+                    if obj.update_condition then
+                        redis.call('SET', obj.update_condition, '1', 'EX', {profile_ttl})
+                    end                  
                 end
             end
 
