@@ -530,8 +530,10 @@ class Profile(object):
             try:
                 value = data[data_type_name + profile_properties.PROFILE_VALUE_POSTFIX]
             except KeyError as e:
-                print(data)
-                raise e
+                if data_type_name + profile_properties.PROFILE_VALUE_POSTFIX == 'ctr__sessions_v':
+                    value = 1
+                else:
+                    raise e
             updated = cls.timestamp_to_datetime(data.get(
                 data_type_name + profile_properties.PROFILE_VALUE_UPDATED_POSTFIX))
             created = cls.timestamp_to_datetime(data.get(
